# Table of Contents

- [automations-with-scripts](<./automations-with-scripts.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Automations with Scripts](<./Automations-with-Scripts.md>)
  - [Overview](<./Automations-with-Scripts/Overview.md>)
  - [Technical Details](<./Automations-with-Scripts/Technical-Details.md>)
  - [Limitations for Fields](<./Automations-with-Scripts/Limitations-for-Fields.md>)
  - [Creating an Automation with a Script](<./Automations-with-Scripts/Creating-an-Automation-with-a-Script.md>)
  - [Calling API Endpoints from Scripts](<./Automations-with-Scripts/Calling-API-Endpoints-from-Scripts.md>)
  - [Code Configurations and Execution Log](<./Automations-with-Scripts/Code-Configurations-and-Execution-Log.md>)
  - [Canceling Subsequent Actions in an Automation](<./Automations-with-Scripts/Canceling-Subsequent-Actions-in-an-Automation.md>)
  - [Examples](<./Automations-with-Scripts/Examples.md>)
